poplar.nn.plot — poplar 0.0.0 documentation

# `poplar.nn.plot`

## Module Contents

### Functions

`loss_plot`(train_losses, test_losses[, filename]) | Simple plot routine for producing a loss curve

poplar.nn.plot.loss_plot(train_losses: list, test_losses: list, filename=None)

  Simple plot routine for producing a loss curve

  Parameters:
    train_losseslist

      List of training data losses

    test_losseslist

      List of testing data losses

    filenamestr, optional

      Output string for the loss curve figure, by default None (in which case, the figure is returned).

  Returns:
    fig (only returned if filename is None)

      The loss curve matplotlib figure.